Function ks_open
Source pub unsafe extern "C" fn ks_open(
arch: Arch,
mode: Mode,
ks: *mut Option<KsHandle>,
) -> Error
Crates a new instance of the Keystone engine.
Inputs:
arch: architecture type (Arch);
mode: hardware mode (Mode);
ks: pointer to a Keystone engine object created by the function if it returns without
error.
Return value:
Error::OK on success, or another value on failure (refer to Error for more
details).